"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_propagation_status import SecurityPropagationStatus
from pensando_dss.psm.model.security_rule_metrics_status import SecurityRuleMetricsStatus
from pensando_dss.psm.model.security_sg_rule_status import SecuritySGRuleStatus
globals()['SecurityPropagationStatus'] = SecurityPropagationStatus
globals()['SecurityRuleMetricsStatus'] = SecurityRuleMetricsStatus
globals()['SecuritySGRuleStatus'] = SecuritySGRuleStatus
from pensando_dss.psm.psm.model.security_network_security_policy_status import SecurityNetworkSecurityPolicyStatus


class TestSecurityNetworkSecurityPolicyStatus(unittest.TestCase):
    """SecurityNetworkSecurityPolicyStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityNetworkSecurityPolicyStatus(self):
        """Test SecurityNetworkSecurityPolicyStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityNetworkSecurityPolicyStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.workload_migration_source import WorkloadMigrationSource
globals()['WorkloadMigrationSource'] = WorkloadMigrationSource
from pensando_dss.psm.psm.model.workload_endpoint_migration_status import WorkloadEndpointMigrationStatus


class TestWorkloadEndpointMigrationStatus(unittest.TestCase):
    """WorkloadEndpointMigrationStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWorkloadEndpointMigrationStatus(self):
        """Test WorkloadEndpointMigrationStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = WorkloadEndpointMigrationStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from psm.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from pensando_dss.psm.model.api_agg_watch_options import ApiAggWatchOptions
from pensando_dss.psm.model.api_kind_watch_options import ApiKindWatchOptions
from pensando_dss.psm.model.api_label import ApiLabel
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.api_list_watch_options import ApiListWatchOptions
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.api_object_ref import ApiObjectRef
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.api_status_result import ApiStatusResult
from pensando_dss.psm.model.api_timestamp import ApiTimestamp
from pensando_dss.psm.model.api_type_meta import ApiTypeMeta
from pensando_dss.psm.model.api_watch_control import ApiWatchControl
from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
from pensando_dss.psm.model.security_alg import SecurityALG
from pensando_dss.psm.model.security_app import SecurityApp
from pensando_dss.psm.model.security_app_list import SecurityAppList
from pensando_dss.psm.model.security_app_spec import SecurityAppSpec
from pensando_dss.psm.model.security_app_status import SecurityAppStatus
from pensando_dss.psm.model.security_auto_msg_app_watch_helper import SecurityAutoMsgAppWatchHelper
from pensando_dss.psm.model.security_auto_msg_app_watch_helper_watch_event import SecurityAutoMsgAppWatchHelperWatchEvent
from pensando_dss.psm.model.security_auto_msg_certificate_watch_helper import SecurityAutoMsgCertificateWatchHelper
from pensando_dss.psm.model.security_auto_msg_certificate_watch_helper_watch_event import SecurityAutoMsgCertificateWatchHelperWatchEvent
from pensando_dss.psm.model.security_auto_msg_firewall_profile_watch_helper import SecurityAutoMsgFirewallProfileWatchHelper
from pensando_dss.psm.model.security_auto_msg_firewall_profile_watch_helper_watch_event import SecurityAutoMsgFirewallProfileWatchHelperWatchEvent
from pensando_dss.psm.model.security_auto_msg_ip_sec_policy_watch_helper import SecurityAutoMsgIPSecPolicyWatchHelper
from pensando_dss.psm.model.security_auto_msg_ip_sec_policy_watch_helper_watch_event import SecurityAutoMsgIPSecPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.security_auto_msg_network_security_policy_watch_helper import SecurityAutoMsgNetworkSecurityPolicyWatchHelper
from pensando_dss.psm.model.security_auto_msg_network_security_policy_watch_helper_watch_event import SecurityAutoMsgNetworkSecurityPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.security_auto_msg_traffic_encryption_policy_watch_helper import SecurityAutoMsgTrafficEncryptionPolicyWatchHelper
from pensando_dss.psm.model.security_auto_msg_traffic_encryption_policy_watch_helper_watch_event import SecurityAutoMsgTrafficEncryptionPolicyWatchHelperWatchEvent
from pensando_dss.psm.model.security_certificate import SecurityCertificate
from pensando_dss.psm.model.security_certificate_list import SecurityCertificateList
from pensando_dss.psm.model.security_certificate_spec import SecurityCertificateSpec
from pensando_dss.psm.model.security_certificate_status import SecurityCertificateStatus
from pensando_dss.psm.model.security_dsc_status import SecurityDSCStatus
from pensando_dss.psm.model.security_dns import SecurityDns
from pensando_dss.psm.model.security_firewall_profile import SecurityFirewallProfile
from pensando_dss.psm.model.security_firewall_profile_list import SecurityFirewallProfileList
from pensando_dss.psm.model.security_firewall_profile_spec import SecurityFirewallProfileSpec
from pensando_dss.psm.model.security_firewall_profile_status import SecurityFirewallProfileStatus
from pensando_dss.psm.model.security_ftp import SecurityFtp
from pensando_dss.psm.model.security_ip_sec_config import SecurityIPSecConfig
from pensando_dss.psm.model.security_ip_sec_match_rule import SecurityIPSecMatchRule
from pensando_dss.psm.model.security_ip_sec_policy import SecurityIPSecPolicy
from pensando_dss.psm.model.security_ip_sec_policy_list import SecurityIPSecPolicyList
from pensando_dss.psm.model.security_ip_sec_policy_rule import SecurityIPSecPolicyRule
from pensando_dss.psm.model.security_ip_sec_policy_spec import SecurityIPSecPolicySpec
from pensando_dss.psm.model.security_ip_sec_policy_status import SecurityIPSecPolicyStatus
from pensando_dss.psm.model.security_ip_sec_rule_status import SecurityIPSecRuleStatus
from pensando_dss.psm.model.security_i_psec_protocol_spec import SecurityIPsecProtocolSpec
from pensando_dss.psm.model.security_icmp import SecurityIcmp
from pensando_dss.psm.model.security_msrpc import SecurityMsrpc
from pensando_dss.psm.model.security_network_security_policy import SecurityNetworkSecurityPolicy
from pensando_dss.psm.model.security_network_security_policy_list import SecurityNetworkSecurityPolicyList
from pensando_dss.psm.model.security_network_security_policy_spec import SecurityNetworkSecurityPolicySpec
from pensando_dss.psm.model.security_network_security_policy_status import SecurityNetworkSecurityPolicyStatus
from pensando_dss.psm.model.security_propagation_status import SecurityPropagationStatus
from pensando_dss.psm.model.security_proto_port import SecurityProtoPort
from pensando_dss.psm.model.security_rule_metrics_status import SecurityRuleMetricsStatus
from pensando_dss.psm.model.security_sg_rule import SecuritySGRule
from pensando_dss.psm.model.security_sg_rule_status import SecuritySGRuleStatus
from pensando_dss.psm.model.security_sunrpc import SecuritySunrpc
from pensando_dss.psm.model.security_tls_protocol_spec import SecurityTLSProtocolSpec
from pensando_dss.psm.model.security_traffic_encryption_policy import SecurityTrafficEncryptionPolicy
from pensando_dss.psm.model.security_traffic_encryption_policy_list import SecurityTrafficEncryptionPolicyList
from pensando_dss.psm.model.security_traffic_encryption_policy_spec import SecurityTrafficEncryptionPolicySpec



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.network_network_interface_spec import NetworkNetworkInterfaceSpec
from pensando_dss.psm.model.network_network_interface_status import NetworkNetworkInterfaceStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['NetworkNetworkInterfaceSpec'] = NetworkNetworkInterfaceSpec
globals()['NetworkNetworkInterfaceStatus'] = NetworkNetworkInterfaceStatus
from pensando_dss.psm.psm.model.network_network_interface import NetworkNetworkInterface


class TestNetworkNetworkInterface(unittest.TestCase):
    """NetworkNetworkInterface unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkNetworkInterface(self):
        """Test NetworkNetworkInterface"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkNetworkInterface()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.network_v1_api import NetworkV1Api  # noqa: E501


class TestNetworkV1Api(unittest.TestCase):
    """NetworkV1Api unit test stubs"""

    def setUp(self):
        self.api = NetworkV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ipam_policy(self):
        """Test case for add_ipam_policy

        Create IPAMPolicy object  # noqa: E501
        """
        pass

    def test_add_ipam_policy1(self):
        """Test case for add_ipam_policy1

        Create IPAMPolicy object  # noqa: E501
        """
        pass

    def test_add_network(self):
        """Test case for add_network

        Create Network object  # noqa: E501
        """
        pass

    def test_add_network1(self):
        """Test case for add_network1

        Create Network object  # noqa: E501
        """
        pass

    def test_add_policer_profile(self):
        """Test case for add_policer_profile

        Create PolicerProfile object  # noqa: E501
        """
        pass

    def test_add_policer_profile1(self):
        """Test case for add_policer_profile1

        Create PolicerProfile object  # noqa: E501
        """
        pass

    def test_add_routing_config(self):
        """Test case for add_routing_config

        Create RoutingConfig object  # noqa: E501
        """
        pass

    def test_add_static_bindings(self):
        """Test case for add_static_bindings

        Add static bindings  # noqa: E501
        """
        pass

    def test_add_static_bindings1(self):
        """Test case for add_static_bindings1

        Add static bindings  # noqa: E501
        """
        pass

    def test_add_virtual_router(self):
        """Test case for add_virtual_router

        Create VirtualRouter object  # noqa: E501
        """
        pass

    def test_add_virtual_router1(self):
        """Test case for add_virtual_router1

        Create VirtualRouter object  # noqa: E501
        """
        pass

    def test_add_virtual_router_peering_group(self):
        """Test case for add_virtual_router_peering_group

        Create VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_add_virtual_router_peering_group1(self):
        """Test case for add_virtual_router_peering_group1

        Create VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_delete_ipam_policy(self):
        """Test case for delete_ipam_policy

        Delete IPAMPolicy object  # noqa: E501
        """
        pass

    def test_delete_ipam_policy1(self):
        """Test case for delete_ipam_policy1

        Delete IPAMPolicy object  # noqa: E501
        """
        pass

    def test_delete_network(self):
        """Test case for delete_network

        Delete Network object  # noqa: E501
        """
        pass

    def test_delete_network1(self):
        """Test case for delete_network1

        Delete Network object  # noqa: E501
        """
        pass

    def test_delete_policer_profile(self):
        """Test case for delete_policer_profile

        Delete PolicerProfile object  # noqa: E501
        """
        pass

    def test_delete_policer_profile1(self):
        """Test case for delete_policer_profile1

        Delete PolicerProfile object  # noqa: E501
        """
        pass

    def test_delete_routing_config(self):
        """Test case for delete_routing_config

        Delete RoutingConfig object  # noqa: E501
        """
        pass

    def test_delete_virtual_router(self):
        """Test case for delete_virtual_router

        Delete VirtualRouter object  # noqa: E501
        """
        pass

    def test_delete_virtual_router1(self):
        """Test case for delete_virtual_router1

        Delete VirtualRouter object  # noqa: E501
        """
        pass

    def test_delete_virtual_router_peering_group(self):
        """Test case for delete_virtual_router_peering_group

        Delete VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_delete_virtual_router_peering_group1(self):
        """Test case for delete_virtual_router_peering_group1

        Delete VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_get_ipam_policy(self):
        """Test case for get_ipam_policy

        Get IPAMPolicy object  # noqa: E501
        """
        pass

    def test_get_ipam_policy1(self):
        """Test case for get_ipam_policy1

        Get IPAMPolicy object  # noqa: E501
        """
        pass

    def test_get_network(self):
        """Test case for get_network

        Get Network object  # noqa: E501
        """
        pass

    def test_get_network1(self):
        """Test case for get_network1

        Get Network object  # noqa: E501
        """
        pass

    def test_get_network_interface(self):
        """Test case for get_network_interface

        Get NetworkInterface object  # noqa: E501
        """
        pass

    def test_get_policer_profile(self):
        """Test case for get_policer_profile

        Get PolicerProfile object  # noqa: E501
        """
        pass

    def test_get_policer_profile1(self):
        """Test case for get_policer_profile1

        Get PolicerProfile object  # noqa: E501
        """
        pass

    def test_get_route_table(self):
        """Test case for get_route_table

        Get RouteTable object  # noqa: E501
        """
        pass

    def test_get_route_table1(self):
        """Test case for get_route_table1

        Get RouteTable object  # noqa: E501
        """
        pass

    def test_get_routing_config(self):
        """Test case for get_routing_config

        Get RoutingConfig object  # noqa: E501
        """
        pass

    def test_get_virtual_router(self):
        """Test case for get_virtual_router

        Get VirtualRouter object  # noqa: E501
        """
        pass

    def test_get_virtual_router1(self):
        """Test case for get_virtual_router1

        Get VirtualRouter object  # noqa: E501
        """
        pass

    def test_get_virtual_router_peering_group(self):
        """Test case for get_virtual_router_peering_group

        Get VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_get_virtual_router_peering_group1(self):
        """Test case for get_virtual_router_peering_group1

        Get VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_label_ipam_policy(self):
        """Test case for label_ipam_policy

        Label IPAMPolicy object  # noqa: E501
        """
        pass

    def test_label_ipam_policy1(self):
        """Test case for label_ipam_policy1

        Label IPAMPolicy object  # noqa: E501
        """
        pass

    def test_label_network(self):
        """Test case for label_network

        Label Network object  # noqa: E501
        """
        pass

    def test_label_network1(self):
        """Test case for label_network1

        Label Network object  # noqa: E501
        """
        pass

    def test_label_network_interface(self):
        """Test case for label_network_interface

        Label NetworkInterface object  # noqa: E501
        """
        pass

    def test_label_policer_profile(self):
        """Test case for label_policer_profile

        Label PolicerProfile object  # noqa: E501
        """
        pass

    def test_label_policer_profile1(self):
        """Test case for label_policer_profile1

        Label PolicerProfile object  # noqa: E501
        """
        pass

    def test_label_routing_config(self):
        """Test case for label_routing_config

        Label RoutingConfig object  # noqa: E501
        """
        pass

    def test_label_virtual_router(self):
        """Test case for label_virtual_router

        Label VirtualRouter object  # noqa: E501
        """
        pass

    def test_label_virtual_router1(self):
        """Test case for label_virtual_router1

        Label VirtualRouter object  # noqa: E501
        """
        pass

    def test_label_virtual_router_peering_group(self):
        """Test case for label_virtual_router_peering_group

        Label VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_label_virtual_router_peering_group1(self):
        """Test case for label_virtual_router_peering_group1

        Label VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_list_ipam_policy(self):
        """Test case for list_ipam_policy

        List IPAMPolicy objects  # noqa: E501
        """
        pass

    def test_list_ipam_policy1(self):
        """Test case for list_ipam_policy1

        List IPAMPolicy objects  # noqa: E501
        """
        pass

    def test_list_network(self):
        """Test case for list_network

        List Network objects  # noqa: E501
        """
        pass

    def test_list_network1(self):
        """Test case for list_network1

        List Network objects  # noqa: E501
        """
        pass

    def test_list_network_interface(self):
        """Test case for list_network_interface

        List NetworkInterface objects  # noqa: E501
        """
        pass

    def test_list_policer_profile(self):
        """Test case for list_policer_profile

        List PolicerProfile objects  # noqa: E501
        """
        pass

    def test_list_policer_profile1(self):
        """Test case for list_policer_profile1

        List PolicerProfile objects  # noqa: E501
        """
        pass

    def test_list_route_table(self):
        """Test case for list_route_table

        List RouteTable objects  # noqa: E501
        """
        pass

    def test_list_route_table1(self):
        """Test case for list_route_table1

        List RouteTable objects  # noqa: E501
        """
        pass

    def test_list_routing_config(self):
        """Test case for list_routing_config

        List RoutingConfig objects  # noqa: E501
        """
        pass

    def test_list_virtual_router(self):
        """Test case for list_virtual_router

        List VirtualRouter objects  # noqa: E501
        """
        pass

    def test_list_virtual_router1(self):
        """Test case for list_virtual_router1

        List VirtualRouter objects  # noqa: E501
        """
        pass

    def test_list_virtual_router_peering_group(self):
        """Test case for list_virtual_router_peering_group

        List VirtualRouterPeeringGroup objects  # noqa: E501
        """
        pass

    def test_list_virtual_router_peering_group1(self):
        """Test case for list_virtual_router_peering_group1

        List VirtualRouterPeeringGroup objects  # noqa: E501
        """
        pass

    def test_update_ipam_policy(self):
        """Test case for update_ipam_policy

        Update IPAMPolicy object  # noqa: E501
        """
        pass

    def test_update_ipam_policy1(self):
        """Test case for update_ipam_policy1

        Update IPAMPolicy object  # noqa: E501
        """
        pass

    def test_update_network(self):
        """Test case for update_network

        Update Network object  # noqa: E501
        """
        pass

    def test_update_network1(self):
        """Test case for update_network1

        Update Network object  # noqa: E501
        """
        pass

    def test_update_network_interface(self):
        """Test case for update_network_interface

        Update NetworkInterface object  # noqa: E501
        """
        pass

    def test_update_policer_profile(self):
        """Test case for update_policer_profile

        Update PolicerProfile object  # noqa: E501
        """
        pass

    def test_update_policer_profile1(self):
        """Test case for update_policer_profile1

        Update PolicerProfile object  # noqa: E501
        """
        pass

    def test_update_routing_config(self):
        """Test case for update_routing_config

        Update RoutingConfig object  # noqa: E501
        """
        pass

    def test_update_virtual_router(self):
        """Test case for update_virtual_router

        Update VirtualRouter object  # noqa: E501
        """
        pass

    def test_update_virtual_router1(self):
        """Test case for update_virtual_router1

        Update VirtualRouter object  # noqa: E501
        """
        pass

    def test_update_virtual_router_peering_group(self):
        """Test case for update_virtual_router_peering_group

        Update VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_update_virtual_router_peering_group1(self):
        """Test case for update_virtual_router_peering_group1

        Update VirtualRouterPeeringGroup object  # noqa: E501
        """
        pass

    def test_watch_ipam_policy(self):
        """Test case for watch_ipam_policy

        Watch IPAMPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ipam_policy1(self):
        """Test case for watch_ipam_policy1

        Watch IPAMPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network(self):
        """Test case for watch_network

        Watch Network objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network1(self):
        """Test case for watch_network1

        Watch Network objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_network_interface(self):
        """Test case for watch_network_interface

        Watch NetworkInterface objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_policer_profile(self):
        """Test case for watch_policer_profile

        Watch PolicerProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_policer_profile1(self):
        """Test case for watch_policer_profile1

        Watch PolicerProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_route_table(self):
        """Test case for watch_route_table

        Watch RouteTable objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_route_table1(self):
        """Test case for watch_route_table1

        Watch RouteTable objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_routing_config(self):
        """Test case for watch_routing_config

        Watch RoutingConfig objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router(self):
        """Test case for watch_virtual_router

        Watch VirtualRouter objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router1(self):
        """Test case for watch_virtual_router1

        Watch VirtualRouter objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router_peering_group(self):
        """Test case for watch_virtual_router_peering_group

        Watch VirtualRouterPeeringGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_virtual_router_peering_group1(self):
        """Test case for watch_virtual_router_peering_group1

        Watch VirtualRouterPeeringGroup objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Auth API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.auth_ldap_server_status import AuthLdapServerStatus
from pensando_dss.psm.model.auth_radius_server_status import AuthRadiusServerStatus
globals()['AuthLdapServerStatus'] = AuthLdapServerStatus
globals()['AuthRadiusServerStatus'] = AuthRadiusServerStatus
from pensando_dss.psm.psm.model.auth_authentication_policy_status import AuthAuthenticationPolicyStatus


class TestAuthAuthenticationPolicyStatus(unittest.TestCase):
    """AuthAuthenticationPolicyStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthAuthenticationPolicyStatus(self):
        """Test AuthAuthenticationPolicyStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthAuthenticationPolicyStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Telemetry_query API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.fields_selector import FieldsSelector
from pensando_dss.psm.model.telemetry_query_bottom_spec import TelemetryQueryBottomSpec
from pensando_dss.psm.model.telemetry_query_pagination_spec import TelemetryQueryPaginationSpec
from pensando_dss.psm.model.telemetry_query_top_spec import TelemetryQueryTopSpec
globals()['FieldsSelector'] = FieldsSelector
globals()['TelemetryQueryBottomSpec'] = TelemetryQueryBottomSpec
globals()['TelemetryQueryPaginationSpec'] = TelemetryQueryPaginationSpec
globals()['TelemetryQueryTopSpec'] = TelemetryQueryTopSpec
from pensando_dss.psm.psm.model.telemetry_query_metrics_query_spec import TelemetryQueryMetricsQuerySpec


class TestTelemetryQueryMetricsQuerySpec(unittest.TestCase):
    """TelemetryQueryMetricsQuerySpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTelemetryQueryMetricsQuerySpec(self):
        """Test TelemetryQueryMetricsQuerySpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TelemetryQueryMetricsQuerySpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_bootstrap_ipam_options import NetworkBootstrapIPAMOptions
from pensando_dss.psm.model.network_ipam_options import NetworkIPAMOptions
globals()['NetworkBootstrapIPAMOptions'] = NetworkBootstrapIPAMOptions
globals()['NetworkIPAMOptions'] = NetworkIPAMOptions
from pensando_dss.psm.psm.model.network_ipam_binding import NetworkIPAMBinding


class TestNetworkIPAMBinding(unittest.TestCase):
    """NetworkIPAMBinding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkIPAMBinding(self):
        """Test NetworkIPAMBinding"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkIPAMBinding()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Orchestration API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.orchestration_v1_api import OrchestrationV1Api  # noqa: E501


class TestOrchestrationV1Api(unittest.TestCase):
    """OrchestrationV1Api unit test stubs"""

    def setUp(self):
        self.api = OrchestrationV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_orchestrator(self):
        """Test case for add_orchestrator

        Create Orchestrator object  # noqa: E501
        """
        pass

    def test_delete_orchestrator(self):
        """Test case for delete_orchestrator

        Delete Orchestrator object  # noqa: E501
        """
        pass

    def test_get_orchestrator(self):
        """Test case for get_orchestrator

        Get Orchestrator object  # noqa: E501
        """
        pass

    def test_label_orchestrator(self):
        """Test case for label_orchestrator

        Label Orchestrator object  # noqa: E501
        """
        pass

    def test_list_orchestrator(self):
        """Test case for list_orchestrator

        List Orchestrator objects  # noqa: E501
        """
        pass

    def test_update_orchestrator(self):
        """Test case for update_orchestrator

        Update Orchestrator object  # noqa: E501
        """
        pass

    def test_watch_orchestrator(self):
        """Test case for watch_orchestrator

        Watch Orchestrator objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.cluster_distributed_service_card_spec import ClusterDistributedServiceCardSpec
from pensando_dss.psm.model.cluster_distributed_service_card_status import ClusterDistributedServiceCardStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['ClusterDistributedServiceCardSpec'] = ClusterDistributedServiceCardSpec
globals()['ClusterDistributedServiceCardStatus'] = ClusterDistributedServiceCardStatus
from pensando_dss.psm.psm.model.cluster_distributed_service_card import ClusterDistributedServiceCard


class TestClusterDistributedServiceCard(unittest.TestCase):
    """ClusterDistributedServiceCard unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterDistributedServiceCard(self):
        """Test ClusterDistributedServiceCard"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterDistributedServiceCard()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Events API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from pensando_dss.psm.api_client import ApiClient, Endpoint as _Endpoint
from pensando_dss.psm.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
import pensando_dss.psm as psm
from pensando_dss.psm.model.events_event import EventsEvent
from pensando_dss.psm.model.events_event_list import EventsEventList


class EventsV1Api(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_get_event(
            self,
            uuid,
            **kwargs
        ):
            """Get specific event  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_get_event(uuid, async_req=True)
            >>> result = thread.get()

            Args:
                uuid (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EventsEvent
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['uuid'] = \
                uuid
            return self.call_with_http_info(**kwargs)

        self.get_get_event = _Endpoint(
            settings={
                'response_type': (EventsEvent,),
                'auth': [],
                'endpoint_path': '/events/v1/events/{UUID}',
                'operation_id': 'get_get_event',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'uuid',
                ],
                'required': [
                    'uuid',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'uuid':
                        (str,),
                },
                'attribute_map': {
                    'uuid': 'UUID',
                },
                'location_map': {
                    'uuid': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_get_event
        )

        def __get_get_events1(
            self,
            **kwargs
        ):
            """get_get_events1  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_get_events1(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EventsEventList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_get_events1 = _Endpoint(
            settings={
                'response_type': (EventsEventList,),
                'auth': [],
                'endpoint_path': '/events/v1/events',
                'operation_id': 'get_get_events1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_get_events1
        )

        def __post_get_events(
            self,
            **kwargs
        ):
            """post_get_events  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.post_get_events(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EventsEventList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.post_get_events = _Endpoint(
            settings={
                'response_type': (EventsEventList,),
                'auth': [],
                'endpoint_path': '/events/v1/events',
                'operation_id': 'post_get_events',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__post_get_events
        )



"""
    Staging API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.staging_v1_api import StagingV1Api  # noqa: E501


class TestStagingV1Api(unittest.TestCase):
    """StagingV1Api unit test stubs"""

    def setUp(self):
        self.api = StagingV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_buffer(self):
        """Test case for add_buffer

        Create Buffer object  # noqa: E501
        """
        pass

    def test_add_buffer1(self):
        """Test case for add_buffer1

        Create Buffer object  # noqa: E501
        """
        pass

    def test_bulkedit(self):
        """Test case for bulkedit

        Create/Update/Delete multiple objects as part of a single request  # noqa: E501
        """
        pass

    def test_bulkedit1(self):
        """Test case for bulkedit1

        Create/Update/Delete multiple objects as part of a single request  # noqa: E501
        """
        pass

    def test_clear(self):
        """Test case for clear

        Clear operations from a configuration buffer  # noqa: E501
        """
        pass

    def test_clear1(self):
        """Test case for clear1

        Clear operations from a configuration buffer  # noqa: E501
        """
        pass

    def test_commit(self):
        """Test case for commit

        Commit a staged configuration buffer  # noqa: E501
        """
        pass

    def test_commit1(self):
        """Test case for commit1

        Commit a staged configuration buffer  # noqa: E501
        """
        pass

    def test_delete_buffer(self):
        """Test case for delete_buffer

        Delete Buffer object  # noqa: E501
        """
        pass

    def test_delete_buffer1(self):
        """Test case for delete_buffer1

        Delete Buffer object  # noqa: E501
        """
        pass

    def test_get_buffer(self):
        """Test case for get_buffer

        Get Buffer object  # noqa: E501
        """
        pass

    def test_get_buffer1(self):
        """Test case for get_buffer1

        Get Buffer object  # noqa: E501
        """
        pass

    def test_list_buffer(self):
        """Test case for list_buffer

        List Buffer objects  # noqa: E501
        """
        pass

    def test_list_buffer1(self):
        """Test case for list_buffer1

        List Buffer objects  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Browser API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.browser_v1_api import BrowserV1Api  # noqa: E501


class TestBrowserV1Api(unittest.TestCase):
    """BrowserV1Api unit test stubs"""

    def setUp(self):
        self.api = BrowserV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_query1(self):
        """Test case for get_query1

        """
        pass

    def test_get_references(self):
        """Test case for get_references

        """
        pass

    def test_get_referrers(self):
        """Test case for get_referrers

        """
        pass

    def test_post_query(self):
        """Test case for post_query

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.monitoring_instance_selector import MonitoringInstanceSelector
from pensando_dss.psm.model.monitoring_measurement_criteria import MonitoringMeasurementCriteria
from pensando_dss.psm.model.monitoring_metric_identifier import MonitoringMetricIdentifier
from pensando_dss.psm.model.monitoring_thresholds import MonitoringThresholds
globals()['MonitoringInstanceSelector'] = MonitoringInstanceSelector
globals()['MonitoringMeasurementCriteria'] = MonitoringMeasurementCriteria
globals()['MonitoringMetricIdentifier'] = MonitoringMetricIdentifier
globals()['MonitoringThresholds'] = MonitoringThresholds
from pensando_dss.psm.psm.model.monitoring_stats_alert_policy_spec import MonitoringStatsAlertPolicySpec


class TestMonitoringStatsAlertPolicySpec(unittest.TestCase):
    """MonitoringStatsAlertPolicySpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringStatsAlertPolicySpec(self):
        """Test MonitoringStatsAlertPolicySpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringStatsAlertPolicySpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    Workload API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from pensando_dss.psm.api_client import ApiClient

# import Configuration
from pensando_dss.psm.configuration import Configuration

# import exceptions
from pensando_dss.psm.exceptions import OpenApiException
from pensando_dss.psm.exceptions import ApiAttributeError
from pensando_dss.psm.exceptions import ApiTypeError
from pensando_dss.psm.exceptions import ApiValueError
from pensando_dss.psm.exceptions import ApiKeyError
from pensando_dss.psm.exceptions import ApiException



"""
    Rollout API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.rollout_v1_api import RolloutV1Api  # noqa: E501


class TestRolloutV1Api(unittest.TestCase):
    """RolloutV1Api unit test stubs"""

    def setUp(self):
        self.api = RolloutV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_rollout(self):
        """Test case for create_rollout

        Start Rollout operation  # noqa: E501
        """
        pass

    def test_get_rollout(self):
        """Test case for get_rollout

        Get Rollout object  # noqa: E501
        """
        pass

    def test_list_rollout(self):
        """Test case for list_rollout

        List Rollout objects  # noqa: E501
        """
        pass

    def test_remove_rollout(self):
        """Test case for remove_rollout

        Remove a Rollout  # noqa: E501
        """
        pass

    def test_stop_rollout(self):
        """Test case for stop_rollout

        Stop a Rollout operation  # noqa: E501
        """
        pass

    def test_update_rollout(self):
        """Test case for update_rollout

        Update Rollout configuration  # noqa: E501
        """
        pass

    def test_watch_rollout(self):
        """Test case for watch_rollout

        Watch Rollout objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import os
import logging
import sys
import json

def get_psm_config():
    HOME = os.environ["HOME"]
    psm_config_path = HOME+"/.psm/config.json"

    config_data = {}
    config_path = psm_config_path
    if not os.path.exists(psm_config_path):
        logging.warn("PSM config does not exist at "+ psm_config_path)
        cont = input("Create config at "+psm_config_path+" ? [y/n]")
        if cont.lower() != 'y':
            sys.exit(1)

        if psm_config_path[0] == "~":
            HOME = os.environ["HOME"]
            config_path = HOME + config_path[1:]
        foldersplit = config_path.split(os.sep)
        if foldersplit[-1]:
            dirpath = (os.sep).join(foldersplit[:-1])
            if not os.path.exists(dirpath):
                os.makedirs((os.sep).join(foldersplit[:-1]))
            config_data = update_psm_config(config_path)
        else:
            logging.error("Invalid PSM config path")
            sys.exit(1)
    else:
        with open(config_path, "r") as f:
            config_data = json.load(f)
    return config_data

def update_psm_config(path):
    psmip = input("Enter PSM IP address: ")
    try:
        with open(path, "w") as f:
            config_data = {"psm-ip": psmip}
            json.dump(config_data, f)
        return config_data
    except:
        logging.error("Unable to write to PSM config at:", path)
        sys.exit(1)

def write_psm_config(config_path, config_data):
    with open(config_path, "w") as f:
        psm_config = json.dump(config_data, f)
    return


"""
    Objstore API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from pensando_dss.psm.api_client import ApiClient, Endpoint as _Endpoint
from pensando_dss.psm.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
import pensando_dss.psm as psm
from pensando_dss.psm.model.api_status import ApiStatus
from pensando_dss.psm.model.objstore_auto_msg_object_watch_helper import ObjstoreAutoMsgObjectWatchHelper
from pensando_dss.psm.model.objstore_object import ObjstoreObject
from pensando_dss.psm.model.objstore_object_list import ObjstoreObjectList
from pensando_dss.psm.model.objstore_stream_chunk import ObjstoreStreamChunk


class ObjstoreV1Api(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __add_object(
            self,
            o_tenant,
            body,
            **kwargs
        ):
            """Create Object object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.add_object(o_tenant, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):
                body (ObjstoreObject):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObject
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.add_object = _Endpoint(
            settings={
                'response_type': (ObjstoreObject,),
                'auth': [],
                'endpoint_path': '/objstore/v1/tenant/{O.Tenant}/{O.Namespace}/objects',
                'operation_id': 'add_object',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'body',
                ],
                'required': [
                    'o_tenant',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'body':
                        (ObjstoreObject,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__add_object
        )

        def __add_object1(
            self,
            o_namespace,
            body,
            **kwargs
        ):
            """Create Object object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.add_object1(o_namespace, body, async_req=True)
            >>> result = thread.get()

            Args:
                o_namespace (str):
                body (ObjstoreObject):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObject
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_namespace'] = \
                o_namespace
            kwargs['body'] = \
                body
            return self.call_with_http_info(**kwargs)

        self.add_object1 = _Endpoint(
            settings={
                'response_type': (ObjstoreObject,),
                'auth': [],
                'endpoint_path': '/objstore/v1/{O.Namespace}/objects',
                'operation_id': 'add_object1',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_namespace',
                    'body',
                ],
                'required': [
                    'o_namespace',
                    'body',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_namespace':
                        (str,),
                    'body':
                        (ObjstoreObject,),
                },
                'attribute_map': {
                    'o_namespace': 'O.Namespace',
                },
                'location_map': {
                    'o_namespace': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__add_object1
        )

        def __delete_object(
            self,
            o_tenant,
            **kwargs
        ):
            """Delete Object object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_object(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObject
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.delete_object = _Endpoint(
            settings={
                'response_type': (ObjstoreObject,),
                'auth': [],
                'endpoint_path': '/objstore/v1/tenant/{O.Tenant}/{O.Namespace}/objects/{O.Name}',
                'operation_id': 'delete_object',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                },
                'location_map': {
                    'o_tenant': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_object
        )

        def __delete_object1(
            self,
            o_namespace,
            **kwargs
        ):
            """Delete Object object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_object1(o_namespace, async_req=True)
            >>> result = thread.get()

            Args:
                o_namespace (str):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObject
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_namespace'] = \
                o_namespace
            return self.call_with_http_info(**kwargs)

        self.delete_object1 = _Endpoint(
            settings={
                'response_type': (ObjstoreObject,),
                'auth': [],
                'endpoint_path': '/objstore/v1/{O.Namespace}/objects/{O.Name}',
                'operation_id': 'delete_object1',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_namespace',
                ],
                'required': [
                    'o_namespace',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_namespace':
                        (str,),
                },
                'attribute_map': {
                    'o_namespace': 'O.Namespace',
                },
                'location_map': {
                    'o_namespace': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_object1
        )

        def __get_download_file(
            self,
            o_tenant,
            **kwargs
        ):
            """Download file  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_download_file(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreStreamChunk
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.get_download_file = _Endpoint(
            settings={
                'response_type': (ObjstoreStreamChunk,),
                'auth': [],
                'endpoint_path': '/objstore/v1/downloads/tenant/{O.Tenant}/{O.Namespace}/{O.Name}',
                'operation_id': 'get_download_file',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    't_kind',
                    'meta_creation_time',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                },
                'location_map': {
                    'o_tenant': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_download_file
        )

        def __get_download_file1(
            self,
            o_namespace,
            **kwargs
        ):
            """Download file  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_download_file1(o_namespace, async_req=True)
            >>> result = thread.get()

            Args:
                o_namespace (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreStreamChunk
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_namespace'] = \
                o_namespace
            return self.call_with_http_info(**kwargs)

        self.get_download_file1 = _Endpoint(
            settings={
                'response_type': (ObjstoreStreamChunk,),
                'auth': [],
                'endpoint_path': '/objstore/v1/downloads/{O.Namespace}/{O.Name}',
                'operation_id': 'get_download_file1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_namespace',
                    't_kind',
                    'meta_creation_time',
                ],
                'required': [
                    'o_namespace',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_namespace':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                },
                'attribute_map': {
                    'o_namespace': 'O.Namespace',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                },
                'location_map': {
                    'o_namespace': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_download_file1
        )

        def __get_download_file_by_prefix(
            self,
            o_tenant,
            **kwargs
        ):
            """Download file by prefix  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_download_file_by_prefix(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreStreamChunk
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.get_download_file_by_prefix = _Endpoint(
            settings={
                'response_type': (ObjstoreStreamChunk,),
                'auth': [],
                'endpoint_path': '/objstore/v1/downloads/all/tenant/{O.Tenant}/{O.Namespace}/{O.Name}',
                'operation_id': 'get_download_file_by_prefix',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    't_kind',
                    'meta_creation_time',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                },
                'location_map': {
                    'o_tenant': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_download_file_by_prefix
        )

        def __get_object(
            self,
            o_tenant,
            **kwargs
        ):
            """Get Object object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_object(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObject
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.get_object = _Endpoint(
            settings={
                'response_type': (ObjstoreObject,),
                'auth': [],
                'endpoint_path': '/objstore/v1/tenant/{O.Tenant}/{O.Namespace}/objects/{O.Name}',
                'operation_id': 'get_object',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    't_kind',
                    'meta_creation_time',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                },
                'location_map': {
                    'o_tenant': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_object
        )

        def __get_object1(
            self,
            o_namespace,
            **kwargs
        ):
            """Get Object object  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_object1(o_namespace, async_req=True)
            >>> result = thread.get()

            Args:
                o_namespace (str):

            Keyword Args:
                t_kind (str): Kind represents the type of the API object.. [optional]
                meta_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObject
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_namespace'] = \
                o_namespace
            return self.call_with_http_info(**kwargs)

        self.get_object1 = _Endpoint(
            settings={
                'response_type': (ObjstoreObject,),
                'auth': [],
                'endpoint_path': '/objstore/v1/{O.Namespace}/objects/{O.Name}',
                'operation_id': 'get_object1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_namespace',
                    't_kind',
                    'meta_creation_time',
                ],
                'required': [
                    'o_namespace',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_namespace':
                        (str,),
                    't_kind':
                        (str,),
                    'meta_creation_time':
                        (datetime,),
                },
                'attribute_map': {
                    'o_namespace': 'O.Namespace',
                    't_kind': 'T.kind',
                    'meta_creation_time': 'meta.creation-time',
                },
                'location_map': {
                    'o_namespace': 'path',
                    't_kind': 'query',
                    'meta_creation_time': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_object1
        )

        def __list_object(
            self,
            o_tenant,
            **kwargs
        ):
            """List Object objects  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_object(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObjectList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.list_object = _Endpoint(
            settings={
                'response_type': (ObjstoreObjectList,),
                'auth': [],
                'endpoint_path': '/objstore/v1/tenant/{O.Tenant}/{O.Namespace}/objects',
                'operation_id': 'list_object',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_object
        )

        def __list_object1(
            self,
            o_namespace,
            **kwargs
        ):
            """List Object objects  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_object1(o_namespace, async_req=True)
            >>> result = thread.get()

            Args:
                o_namespace (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreObjectList
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_namespace'] = \
                o_namespace
            return self.call_with_http_info(**kwargs)

        self.list_object1 = _Endpoint(
            settings={
                'response_type': (ObjstoreObjectList,),
                'auth': [],
                'endpoint_path': '/objstore/v1/{O.Namespace}/objects',
                'operation_id': 'list_object1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_namespace',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_namespace',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_namespace':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_namespace': 'O.Namespace',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_namespace': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__list_object1
        )

        def __watch_object(
            self,
            o_tenant,
            **kwargs
        ):
            """Watch Object objects. Supports WebSockets or HTTP long poll  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.watch_object(o_tenant, async_req=True)
            >>> result = thread.get()

            Args:
                o_tenant (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreAutoMsgObjectWatchHelper
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_tenant'] = \
                o_tenant
            return self.call_with_http_info(**kwargs)

        self.watch_object = _Endpoint(
            settings={
                'response_type': (ObjstoreAutoMsgObjectWatchHelper,),
                'auth': [],
                'endpoint_path': '/objstore/v1/watch/tenant/{O.Tenant}/{O.Namespace}/objects',
                'operation_id': 'watch_object',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_tenant',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_tenant',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_tenant':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_tenant': 'O.Tenant',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_tenant': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__watch_object
        )

        def __watch_object1(
            self,
            o_namespace,
            **kwargs
        ):
            """Watch Object objects. Supports WebSockets or HTTP long poll  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.watch_object1(o_namespace, async_req=True)
            >>> result = thread.get()

            Args:
                o_namespace (str):

            Keyword Args:
                o_name (str): Name of the object, unique within a Namespace for scoped objects. Must start and end with alpha numeric and can have alphanumeric, -, _, . Length of string should be between 2 and 64.. [optional]
                o_creation_time (datetime): CreationTime is the creation time of the object. System generated and updated, not updatable by user.. [optional]
                field_change_selector ([str]): FieldChangeSelector specifies to generate a watch notification on change in field(s) specified.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ObjstoreAutoMsgObjectWatchHelper
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['o_namespace'] = \
                o_namespace
            return self.call_with_http_info(**kwargs)

        self.watch_object1 = _Endpoint(
            settings={
                'response_type': (ObjstoreAutoMsgObjectWatchHelper,),
                'auth': [],
                'endpoint_path': '/objstore/v1/watch/{O.Namespace}/objects',
                'operation_id': 'watch_object1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'o_namespace',
                    'o_name',
                    'o_creation_time',
                    'field_change_selector',
                ],
                'required': [
                    'o_namespace',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'o_namespace':
                        (str,),
                    'o_name':
                        (str,),
                    'o_creation_time':
                        (datetime,),
                    'field_change_selector':
                        ([str],),
                },
                'attribute_map': {
                    'o_namespace': 'O.Namespace',
                    'o_name': 'O.name',
                    'o_creation_time': 'O.creation-time',
                    'field_change_selector': 'field-change-selector',
                },
                'location_map': {
                    'o_namespace': 'path',
                    'o_name': 'query',
                    'o_creation_time': 'query',
                    'field_change_selector': 'query',
                },
                'collection_format_map': {
                    'field_change_selector': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__watch_object1
        )



"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_flow_spec import SysruntimeFlowSpec
globals()['SysruntimeFlowSpec'] = SysruntimeFlowSpec
from pensando_dss.psm.psm.model.sysruntime_hw_connection_spec import SysruntimeHWConnectionSpec


class TestSysruntimeHWConnectionSpec(unittest.TestCase):
    """SysruntimeHWConnectionSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeHWConnectionSpec(self):
        """Test SysruntimeHWConnectionSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeHWConnectionSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.fields_selector import FieldsSelector
from pensando_dss.psm.model.monitoring_email_export import MonitoringEmailExport
from pensando_dss.psm.model.monitoring_snmp_export import MonitoringSNMPExport
from pensando_dss.psm.model.monitoring_syslog_export import MonitoringSyslogExport
globals()['FieldsSelector'] = FieldsSelector
globals()['MonitoringEmailExport'] = MonitoringEmailExport
globals()['MonitoringSNMPExport'] = MonitoringSNMPExport
globals()['MonitoringSyslogExport'] = MonitoringSyslogExport
from pensando_dss.psm.psm.model.monitoring_alert_destination_spec import MonitoringAlertDestinationSpec


class TestMonitoringAlertDestinationSpec(unittest.TestCase):
    """MonitoringAlertDestinationSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringAlertDestinationSpec(self):
        """Test MonitoringAlertDestinationSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringAlertDestinationSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Telemetry_query API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.telemetry_query_v1_api import TelemetryQueryV1Api  # noqa: E501


class TestTelemetryQueryV1Api(unittest.TestCase):
    """TelemetryQueryV1Api unit test stubs"""

    def setUp(self):
        self.api = TelemetryQueryV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_metrics1(self):
        """Test case for get_metrics1

        telemetry metrics query  # noqa: E501
        """
        pass

    def test_post_metrics(self):
        """Test case for post_metrics

        telemetry metrics query  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Auth API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.auth_v1_api import AuthV1Api  # noqa: E501


class TestAuthV1Api(unittest.TestCase):
    """AuthV1Api unit test stubs"""

    def setUp(self):
        self.api = AuthV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_authentication_policy(self):
        """Test case for add_authentication_policy

        Create AuthenticationPolicy object  # noqa: E501
        """
        pass

    def test_add_role(self):
        """Test case for add_role

        Create Role object  # noqa: E501
        """
        pass

    def test_add_role1(self):
        """Test case for add_role1

        Create Role object  # noqa: E501
        """
        pass

    def test_add_role_binding(self):
        """Test case for add_role_binding

        Create RoleBinding object  # noqa: E501
        """
        pass

    def test_add_role_binding1(self):
        """Test case for add_role_binding1

        Create RoleBinding object  # noqa: E501
        """
        pass

    def test_add_user(self):
        """Test case for add_user

        Create User object  # noqa: E501
        """
        pass

    def test_add_user1(self):
        """Test case for add_user1

        Create User object  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Delete Role object  # noqa: E501
        """
        pass

    def test_delete_role1(self):
        """Test case for delete_role1

        Delete Role object  # noqa: E501
        """
        pass

    def test_delete_role_binding(self):
        """Test case for delete_role_binding

        Delete RoleBinding object  # noqa: E501
        """
        pass

    def test_delete_role_binding1(self):
        """Test case for delete_role_binding1

        Delete RoleBinding object  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete User object  # noqa: E501
        """
        pass

    def test_delete_user1(self):
        """Test case for delete_user1

        Delete User object  # noqa: E501
        """
        pass

    def test_get_authentication_policy(self):
        """Test case for get_authentication_policy

        Get AuthenticationPolicy object  # noqa: E501
        """
        pass

    def test_get_role(self):
        """Test case for get_role

        Get Role object  # noqa: E501
        """
        pass

    def test_get_role1(self):
        """Test case for get_role1

        Get Role object  # noqa: E501
        """
        pass

    def test_get_role_binding(self):
        """Test case for get_role_binding

        Get RoleBinding object  # noqa: E501
        """
        pass

    def test_get_role_binding1(self):
        """Test case for get_role_binding1

        Get RoleBinding object  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get User object  # noqa: E501
        """
        pass

    def test_get_user1(self):
        """Test case for get_user1

        Get User object  # noqa: E501
        """
        pass

    def test_get_user_preference(self):
        """Test case for get_user_preference

        Get UserPreference object  # noqa: E501
        """
        pass

    def test_get_user_preference1(self):
        """Test case for get_user_preference1

        Get UserPreference object  # noqa: E501
        """
        pass

    def test_is_authorized(self):
        """Test case for is_authorized

        Review authorization for user  # noqa: E501
        """
        pass

    def test_is_authorized1(self):
        """Test case for is_authorized1

        Review authorization for user  # noqa: E501
        """
        pass

    def test_label_authentication_policy(self):
        """Test case for label_authentication_policy

        Label AuthenticationPolicy object  # noqa: E501
        """
        pass

    def test_label_role(self):
        """Test case for label_role

        Label Role object  # noqa: E501
        """
        pass

    def test_label_role1(self):
        """Test case for label_role1

        Label Role object  # noqa: E501
        """
        pass

    def test_label_role_binding(self):
        """Test case for label_role_binding

        Label RoleBinding object  # noqa: E501
        """
        pass

    def test_label_role_binding1(self):
        """Test case for label_role_binding1

        Label RoleBinding object  # noqa: E501
        """
        pass

    def test_label_user(self):
        """Test case for label_user

        Label User object  # noqa: E501
        """
        pass

    def test_label_user1(self):
        """Test case for label_user1

        Label User object  # noqa: E501
        """
        pass

    def test_label_user_preference(self):
        """Test case for label_user_preference

        Label UserPreference object  # noqa: E501
        """
        pass

    def test_label_user_preference1(self):
        """Test case for label_user_preference1

        Label UserPreference object  # noqa: E501
        """
        pass

    def test_ldap_bind_check(self):
        """Test case for ldap_bind_check

        Test LDAP bind operation  # noqa: E501
        """
        pass

    def test_ldap_connection_check(self):
        """Test case for ldap_connection_check

        Test LDAP connection  # noqa: E501
        """
        pass

    def test_list_role(self):
        """Test case for list_role

        List Role objects  # noqa: E501
        """
        pass

    def test_list_role1(self):
        """Test case for list_role1

        List Role objects  # noqa: E501
        """
        pass

    def test_list_role_binding(self):
        """Test case for list_role_binding

        List RoleBinding objects  # noqa: E501
        """
        pass

    def test_list_role_binding1(self):
        """Test case for list_role_binding1

        List RoleBinding objects  # noqa: E501
        """
        pass

    def test_list_user(self):
        """Test case for list_user

        List User objects  # noqa: E501
        """
        pass

    def test_list_user1(self):
        """Test case for list_user1

        List User objects  # noqa: E501
        """
        pass

    def test_password_change(self):
        """Test case for password_change

        Change user password  # noqa: E501
        """
        pass

    def test_password_change1(self):
        """Test case for password_change1

        Change user password  # noqa: E501
        """
        pass

    def test_password_reset(self):
        """Test case for password_reset

        Reset user password  # noqa: E501
        """
        pass

    def test_password_reset1(self):
        """Test case for password_reset1

        Reset user password  # noqa: E501
        """
        pass

    def test_token_secret_generate(self):
        """Test case for token_secret_generate

        Generate secret for token signing  # noqa: E501
        """
        pass

    def test_unlock(self):
        """Test case for unlock

        Unlock user  # noqa: E501
        """
        pass

    def test_unlock1(self):
        """Test case for unlock1

        Unlock user  # noqa: E501
        """
        pass

    def test_update_authentication_policy(self):
        """Test case for update_authentication_policy

        Update AuthenticationPolicy object  # noqa: E501
        """
        pass

    def test_update_role(self):
        """Test case for update_role

        Update Role object  # noqa: E501
        """
        pass

    def test_update_role1(self):
        """Test case for update_role1

        Update Role object  # noqa: E501
        """
        pass

    def test_update_role_binding(self):
        """Test case for update_role_binding

        Update RoleBinding object  # noqa: E501
        """
        pass

    def test_update_role_binding1(self):
        """Test case for update_role_binding1

        Update RoleBinding object  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update User object  # noqa: E501
        """
        pass

    def test_update_user1(self):
        """Test case for update_user1

        Update User object  # noqa: E501
        """
        pass

    def test_update_user_preference(self):
        """Test case for update_user_preference

        Update UserPreference object  # noqa: E501
        """
        pass

    def test_update_user_preference1(self):
        """Test case for update_user_preference1

        Update UserPreference object  # noqa: E501
        """
        pass

    def test_watch_authentication_policy(self):
        """Test case for watch_authentication_policy

        Watch AuthenticationPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_role(self):
        """Test case for watch_role

        Watch Role objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_role1(self):
        """Test case for watch_role1

        Watch Role objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_role_binding(self):
        """Test case for watch_role_binding

        Watch RoleBinding objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_role_binding1(self):
        """Test case for watch_role_binding1

        Watch RoleBinding objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_user(self):
        """Test case for watch_user

        Watch User objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_user1(self):
        """Test case for watch_user1

        Watch User objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_user_preference(self):
        """Test case for watch_user_preference

        Watch UserPreference objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_user_preference1(self):
        """Test case for watch_user_preference1

        Watch UserPreference objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.cluster_v1_api import ClusterV1Api  # noqa: E501


class TestClusterV1Api(unittest.TestCase):
    """ClusterV1Api unit test stubs"""

    def setUp(self):
        self.api = ClusterV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_configuration_snapshot(self):
        """Test case for add_configuration_snapshot

        Create ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_add_distributed_service_card(self):
        """Test case for add_distributed_service_card

        Create DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_add_distributed_service_entity(self):
        """Test case for add_distributed_service_entity

        Create DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_add_dsc_profile(self):
        """Test case for add_dsc_profile

        Create DSCProfile object  # noqa: E501
        """
        pass

    def test_add_host(self):
        """Test case for add_host

        Create Host object  # noqa: E501
        """
        pass

    def test_add_license(self):
        """Test case for add_license

        Create License object  # noqa: E501
        """
        pass

    def test_add_node(self):
        """Test case for add_node

        Create Node object  # noqa: E501
        """
        pass

    def test_add_tenant(self):
        """Test case for add_tenant

        Create Tenant object  # noqa: E501
        """
        pass

    def test_auth_bootstrap_complete(self):
        """Test case for auth_bootstrap_complete

        Mark bootstrapping as complete for the cluster  # noqa: E501
        """
        pass

    def test_delete_configuration_snapshot(self):
        """Test case for delete_configuration_snapshot

        Delete ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_delete_distributed_service_card(self):
        """Test case for delete_distributed_service_card

        Delete DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_delete_distributed_service_entity(self):
        """Test case for delete_distributed_service_entity

        Delete DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_delete_dsc_profile(self):
        """Test case for delete_dsc_profile

        Delete DSCProfile object  # noqa: E501
        """
        pass

    def test_delete_host(self):
        """Test case for delete_host

        Delete Host object  # noqa: E501
        """
        pass

    def test_delete_node(self):
        """Test case for delete_node

        Delete Node object  # noqa: E501
        """
        pass

    def test_delete_tenant(self):
        """Test case for delete_tenant

        Delete Tenant object  # noqa: E501
        """
        pass

    def test_get_cluster(self):
        """Test case for get_cluster

        Get Cluster object  # noqa: E501
        """
        pass

    def test_get_cluster_profile(self):
        """Test case for get_cluster_profile

        Get ClusterProfile object  # noqa: E501
        """
        pass

    def test_get_configuration_snapshot(self):
        """Test case for get_configuration_snapshot

        Get ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_get_distributed_service_card(self):
        """Test case for get_distributed_service_card

        Get DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_get_distributed_service_entity(self):
        """Test case for get_distributed_service_entity

        Get DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_get_dsc_profile(self):
        """Test case for get_dsc_profile

        Get DSCProfile object  # noqa: E501
        """
        pass

    def test_get_host(self):
        """Test case for get_host

        Get Host object  # noqa: E501
        """
        pass

    def test_get_license(self):
        """Test case for get_license

        Get License object  # noqa: E501
        """
        pass

    def test_get_node(self):
        """Test case for get_node

        Get Node object  # noqa: E501
        """
        pass

    def test_get_snapshot_restore(self):
        """Test case for get_snapshot_restore

        Get SnapshotRestore object  # noqa: E501
        """
        pass

    def test_get_tenant(self):
        """Test case for get_tenant

        Get Tenant object  # noqa: E501
        """
        pass

    def test_get_version(self):
        """Test case for get_version

        Get Version object  # noqa: E501
        """
        pass

    def test_label_cluster(self):
        """Test case for label_cluster

        Label Cluster object  # noqa: E501
        """
        pass

    def test_label_cluster_profile(self):
        """Test case for label_cluster_profile

        Label ClusterProfile object  # noqa: E501
        """
        pass

    def test_label_configuration_snapshot(self):
        """Test case for label_configuration_snapshot

        Label ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_label_distributed_service_card(self):
        """Test case for label_distributed_service_card

        Label DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_label_distributed_service_entity(self):
        """Test case for label_distributed_service_entity

        Label DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_label_dsc_profile(self):
        """Test case for label_dsc_profile

        Label DSCProfile object  # noqa: E501
        """
        pass

    def test_label_host(self):
        """Test case for label_host

        Label Host object  # noqa: E501
        """
        pass

    def test_label_license(self):
        """Test case for label_license

        Label License object  # noqa: E501
        """
        pass

    def test_label_node(self):
        """Test case for label_node

        Label Node object  # noqa: E501
        """
        pass

    def test_label_tenant(self):
        """Test case for label_tenant

        Label Tenant object  # noqa: E501
        """
        pass

    def test_list_distributed_service_card(self):
        """Test case for list_distributed_service_card

        List DistributedServiceCard objects  # noqa: E501
        """
        pass

    def test_list_distributed_service_entity(self):
        """Test case for list_distributed_service_entity

        List DistributedServiceEntity objects  # noqa: E501
        """
        pass

    def test_list_dsc_profile(self):
        """Test case for list_dsc_profile

        List DSCProfile objects  # noqa: E501
        """
        pass

    def test_list_host(self):
        """Test case for list_host

        List Host objects  # noqa: E501
        """
        pass

    def test_list_node(self):
        """Test case for list_node

        List Node objects  # noqa: E501
        """
        pass

    def test_list_tenant(self):
        """Test case for list_tenant

        List Tenant objects  # noqa: E501
        """
        pass

    def test_restore(self):
        """Test case for restore

        Restore Configuration  # noqa: E501
        """
        pass

    def test_save(self):
        """Test case for save

        Perform a Configuation Snapshot  # noqa: E501
        """
        pass

    def test_update_cluster(self):
        """Test case for update_cluster

        Update Cluster object  # noqa: E501
        """
        pass

    def test_update_cluster_profile(self):
        """Test case for update_cluster_profile

        Update ClusterProfile object  # noqa: E501
        """
        pass

    def test_update_configuration_snapshot(self):
        """Test case for update_configuration_snapshot

        Update ConfigurationSnapshot object  # noqa: E501
        """
        pass

    def test_update_distributed_service_card(self):
        """Test case for update_distributed_service_card

        Update DistributedServiceCard object  # noqa: E501
        """
        pass

    def test_update_distributed_service_entity(self):
        """Test case for update_distributed_service_entity

        Update DistributedServiceEntity object  # noqa: E501
        """
        pass

    def test_update_dsc_profile(self):
        """Test case for update_dsc_profile

        Update DSCProfile object  # noqa: E501
        """
        pass

    def test_update_host(self):
        """Test case for update_host

        Update Host object  # noqa: E501
        """
        pass

    def test_update_license(self):
        """Test case for update_license

        Update License object  # noqa: E501
        """
        pass

    def test_update_node(self):
        """Test case for update_node

        Update Node object  # noqa: E501
        """
        pass

    def test_update_tenant(self):
        """Test case for update_tenant

        Update Tenant object  # noqa: E501
        """
        pass

    def test_update_tls_config(self):
        """Test case for update_tls_config

        Update TLS Configuration for cluster  # noqa: E501
        """
        pass

    def test_update_version(self):
        """Test case for update_version

        Update Version object  # noqa: E501
        """
        pass

    def test_watch_cluster(self):
        """Test case for watch_cluster

        Watch Cluster objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_cluster_profile(self):
        """Test case for watch_cluster_profile

        Watch ClusterProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_configuration_snapshot(self):
        """Test case for watch_configuration_snapshot

        Watch ConfigurationSnapshot objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_distributed_service_card(self):
        """Test case for watch_distributed_service_card

        Watch DistributedServiceCard objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_distributed_service_entity(self):
        """Test case for watch_distributed_service_entity

        Watch DistributedServiceEntity objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_dsc_profile(self):
        """Test case for watch_dsc_profile

        Watch DSCProfile objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_host(self):
        """Test case for watch_host

        Watch Host objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_node(self):
        """Test case for watch_node

        Watch Node objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_tenant(self):
        """Test case for watch_tenant

        Watch Tenant objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_version(self):
        """Test case for watch_version

        Watch Version objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.psm.model.evpn_route_evpn_type5_route import EVPNRouteEVPNType5Route


class TestEVPNRouteEVPNType5Route(unittest.TestCase):
    """EVPNRouteEVPNType5Route unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEVPNRouteEVPNType5Route(self):
        """Test EVPNRouteEVPNType5Route"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EVPNRouteEVPNType5Route()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Audit API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.audit_v1_api import AuditV1Api  # noqa: E501


class TestAuditV1Api(unittest.TestCase):
    """AuditV1Api unit test stubs"""

    def setUp(self):
        self.api = AuditV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_get_event(self):
        """Test case for get_get_event

        Fetches an audit event given its uuid  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_flow_key_l2 import SysruntimeFlowKeyL2
from pensando_dss.psm.model.sysruntime_flow_key_v4 import SysruntimeFlowKeyV4
globals()['SysruntimeFlowKeyL2'] = SysruntimeFlowKeyL2
globals()['SysruntimeFlowKeyV4'] = SysruntimeFlowKeyV4
from pensando_dss.psm.psm.model.sysruntime_flow_key import SysruntimeFlowKey


class TestSysruntimeFlowKey(unittest.TestCase):
    """SysruntimeFlowKey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeFlowKey(self):
        """Test SysruntimeFlowKey"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeFlowKey()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
